import { readFile, rm, stat, writeFile } from 'node:fs/promises';
import { CODE_PUSHUP_UNICODE_LOGO } from '@code-pushup/utils';
import { NX_JSON_CONTENT, NX_JSON_FILENAME, PROJECT_JSON_CONTENT, PROJECT_JSON_FILENAME, PROJECT_NAME, } from './constants.js';
export async function setupFile(filename, content = '') {
    const setupResult = {
        filename,
        teardown: false,
    };
    try {
        const stats = await stat(filename);
        if (!stats.isFile()) {
            await writeFile(filename, content);
        }
    }
    catch (error) {
        if (error instanceof Error &&
            error.message.includes('no such file or directory')) {
            await writeFile(filename, content);
            return {
                ...setupResult,
                teardown: true,
            };
        }
        else {
            console.error(error);
        }
    }
    return setupResult;
}
export function parseNxProcessOutput(output) {
    return output.trim().replace('NX', CODE_PUSHUP_UNICODE_LOGO);
}
export async function setupNxContext() {
    const { teardown: nxJsonTeardown } = await setupFile(NX_JSON_FILENAME, NX_JSON_CONTENT);
    const { teardown: projectJsonTeardown } = await setupFile(PROJECT_JSON_FILENAME, PROJECT_JSON_CONTENT);
    const projectJsonContent = await readFile(PROJECT_JSON_FILENAME, 'utf8');
    const { name = PROJECT_NAME } = JSON.parse(projectJsonContent);
    return {
        nxJsonTeardown,
        projectJsonTeardown,
        projectName: name,
    };
}
export async function teardownNxContext({ nxJsonTeardown, projectJsonTeardown, }) {
    const filesToDelete = [
        ...(nxJsonTeardown ? [NX_JSON_FILENAME] : []),
        ...(projectJsonTeardown ? [PROJECT_JSON_FILENAME] : []),
    ];
    await Promise.all(filesToDelete.map(file => rm(file)));
}
//# sourceMappingURL=utils.js.map